from django.apps import AppConfig


class CustomDevelopmentConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'custom_development'
    verbose_name = 'Dadus Custom Ba Livru Administrasaun Dezenvolvimentu'
